@@ -1,5 +1,5 @@
 use serde_json::{json, Value};
-use shumai::{config, Context, ShumaiBench, ShumaiResult};
+use shumai::{config, Context, ShumaiBench};
 
 #[derive(Debug, Clone, serde::Serialize, serde::Deserialize)]
 pub enum Workload {
@@ -162,33 +162,8 @@ fn write_json() {
         let file_path = result.write_json().unwrap();
 
         let written_data = std::fs::read_to_string(file_path).unwrap();
-        let result: ShumaiResult<Foo, usize> = serde_json::from_str(&written_data).unwrap();
-        assert_eq!(result.config.time, 1);
-        assert_eq!(result.config.threads, vec![1, 2, 3]);
-        assert_eq!(result.bench_results.len(), 3);
-    }
-}
-
-#[test]
-#[cfg(feature = "perf")]
-#[cfg_attr(miri, ignore)]
-fn simple_perf() {
-    let config = Foo::load().expect("Failed to parse config!");
-    let repeat = 1;
-
-    let c = config.first().unwrap();
-    let mut benchmark = TestBench::default();
-    let result = shumai::run(&mut benchmark, c, repeat);
-    let bench_results = result.bench_results;
-    assert_eq!(bench_results.len(), c.threads.len());
-    for rv in bench_results {
-        let perf = rv.perf;
-        // These counters should all be positive
-        assert!(perf.cycles > 0);
-        assert!(perf.inst > 0);
-        assert!(perf.branch_miss > 0);
-        assert!(perf.branches > 0);
-        assert!(perf.cache_reference > 0);
-        assert!(perf.cache_miss > 0);
+        let result: serde_json::Value = serde_json::from_str(&written_data).unwrap();
+        assert_eq!(result["config"]["time"].as_u64().unwrap(), 1);
+        assert_eq!(result["config"]["threads"].as_array().unwrap().len(), 3);
     }
 }
